==> fox-wamp-0.6.9.tgz: package/bin/with_auth.js <==
//
// This is authenticate router example
//

var Router = require('../index')
var TopicPattern = require('../lib/topic_pattern')
var program = require('commander')

program
  .option('-p, --port <port>', 'Server IP port', 9000)
  .parse(process.argv)

let app = new Router()
app.setLogTrace(true)

let WampAuth = function () {
  this.getAuthMethods = function () {
    return ['ticket']
  }
  this.ticket_auth = function (realmName, secureDetails, secret, extra, cb) {
    console.log('TICKET_AUTH:', secureDetails, secret, extra)
    app.getRealm(realmName, (realm) => {
      let api = realm.wampApi()
      let found = false
      api.subscribe('sys.user.info.'+secureDetails.authid, (id, args, kwargs) => {
        if (kwargs.password === secret) {
          cb(undefined, kwargs)
        } else {
          cb(new Error('authentication_failed'))
        }
        found = true
      }).then((subId) => {
        if (!found) {
          cb(new Error('authentication_failed'))
        }
        api.unsubscribe(subId)
      })
    })
  }
  this.wampcra_extra = function (realmName, secureDetails, cb) {
    cb(undefined, 'some-random-string')
  }
  this.wampcra_auth = function (realmName, secureDetails, secret, extra, cb) {
    console.log(realmName, secureDetails, secret, extra)
    
  }
  this.authorize = function (session, funcClass, uniUri) {
    let userDetails = session.getUserDetails()
    console.log('authorize:', funcClass, uniUri, 'userDetails:', userDetails)
    if (userDetails.role === 'admin') {
      return true
    }
    else {
      return !TopicPattern.intersect(uniUri, ['sys', 'user', 'info', '#'])
    }
  }
}

app.getRealm('realm1', function (realm) {
  var api = realm.wampApi()
  // create demo database
  api.publish('sys.user.info.joe', [], { role: 'user', password: 'joe-secret' }, { retain:true })
  api.publish('sys.user.info.admin', [], { role: 'admin', password: 'admin-secret' }, { retain:true })
})

console.log('Listening port:', program.port)
app.listenWAMP({ port: program.port }, new WampAuth())

==> fox-wamp-0.7.1.tgz: package/bin/with_auth.js <==
//
// This is authenticate router example
//

const Router = require('../index')
const TopicPattern = require('../lib/topic_pattern')
const program = require('commander')

program
  .option('-p, --port <port>', 'Server IP port', 9000)
  .parse(process.argv)

const app = new Router()
app.setLogTrace(true)

const WampAuth = function () {
  this.getAuthMethods = function () {
    return ['ticket']
  }
  this.ticket_auth = function (realmName, secureDetails, secret, extra, cb) {
    console.log('TICKET_AUTH:', secureDetails, secret, extra)
    app.getRealm(realmName, (realm) => {
      let api = realm.wampApi()
      let found = false
      api.subscribe('sys.user.info.'+secureDetails.authid, (id, args, kwargs) => {
        if (kwargs.password === secret) {
          cb(undefined, kwargs)
        } else {
          cb(new Error('authentication_failed'))
        }
        found = true
      }).then((subId) => {
        if (!found) {
          cb(new Error('authentication_failed'))
        }
        api.unsubscribe(subId)
      })
    })
  }
  this.wampcra_extra = function (realmName, secureDetails, cb) {
    cb(undefined, 'some-random-string')
  }
  this.wampcra_auth = function (realmName, secureDetails, secret, extra, cb) {
    console.log(realmName, secureDetails, secret, extra)
  }
  this.authorize = function (session, funcClass, uniUri) {
    const userDetails = session.getUserDetails()
    console.log('authorize:', funcClass, uniUri, 'userDetails:', userDetails)
    if (userDetails.role === 'admin') {
      return true
    } else {
      return !TopicPattern.intersect(uniUri, ['sys', 'user', 'info', '#'])
    }
  }
}

app.getRealm('realm1', function (realm) {
  var api = realm.wampApi()
  // create demo database
  api.publish('sys.user.info.joe', [], { role: 'user', password: 'joe-secret' }, { retain:true })
  api.publish('sys.user.info.admin', [], { role: 'admin', password: 'admin-secret' }, { retain:true })
})

console.log('Listening port:', program.port)
app.listenWAMP({ port: program.port }, new WampAuth())
